@@ -401,7 +401,7 @@ class UBX_CFGVAL_Frame(Frame):
 
         if valid_entry:
             msg = UBXMessage.config_set(layers, transaction, cfgData)
-            self.__app.serial_handler.serial_write(msg.serialize())
+            self.__app.stream_handler.serial_write(msg.serialize())
             self._ent_val.configure(bg=ENTCOL)
             self._lbl_send_command.config(image=self._img_pending)
             self.__container.set_status("CFG-VALSET SET message sent", "blue")
@@ -437,7 +437,7 @@ class UBX_CFGVAL_Frame(Frame):
             self._cfgval_keyname,
         ]
         msg = UBXMessage.config_del(layers, transaction, key)
-        self.__app.serial_handler.serial_write(msg.serialize())
+        self.__app.stream_handler.serial_write(msg.serialize())
         self._ent_val.configure(bg=ENTCOL)
         self._lbl_send_command.config(image=self._img_pending)
         self.__container.set_status("CFG-VALDEL SET message sent", "blue")
@@ -462,7 +462,7 @@ class UBX_CFGVAL_Frame(Frame):
             self._cfgval_keyname,
         ]
         msg = UBXMessage.config_poll(layers, transaction, keys)
-        self.__app.serial_handler.serial_write(msg.serialize())
+        self.__app.stream_handler.serial_write(msg.serialize())
         self._ent_val.configure(bg=ENTCOL)
         self._lbl_send_command.config(image=self._img_pending)
         self.__container.set_status("CFG-VALGET POLL message sent", "blue")
